@@ -37,6 +37,6 @@ fi
 ############################
 # Unit tests and doc tests #
 ############################
-RUST_BACKTRACE=1 cargo test
+RUST_BACKTRACE=1 cargo test --all-features
 
 cargo clean
